'use strict';

var separate = 'separate';
const x = 2;
console.log('separate');

exports.default = separate;
exports.x = x;
